Welcome to pyoadr-ven's documentation!
======================================

.. toctree::
   :hidden:
   :includehidden:
   :caption: Contents:

   installation
   usage
   modules
   contributing
   history

.. include:: ../README.rst

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
